@@ -6,6 +6,7 @@ Created on Mon Apr 13 09:47:41 2020
 """
 
 import matplotlib.pyplot as plt
+from matplotlib import cm
 import numpy as np
 import pandas as pd
 from glob import glob
@@ -125,31 +126,6 @@ class ANA():
                         
         return d.groupby(['Channel', 'Backward']).Value.describe()
 
-    def hist(self, spots, channel, backward, *args, **kwargs):
-        dd = self.channelData(spots, channel, backward).Value.dropna().values
-        plt.hist(dd, **kwargs)
-        plt.xlabel(channel)
-        plt.ylabel('Counts')
-
-    def image(self, spot, channel, backward, *args, **kwargs):
-        if isinstance(spot, list):
-            print('Can only show map of one spot at a time')
-            return
-
-        ar = self.channelData(spot, channel, backward, fill_empty=True).Value.values
-        
-        sz = self.param.MapPixSize[spot-1]
-        ar = ar.reshape((sz, sz)).copy()
-        ar[::2] = np.fliplr(ar[::2])
-
-        mSize = self.param.MapSize[spot-1]
-        plt.imshow(ar, origin='bottomleft', extent=(0, mSize, 0, mSize), **kwargs)
-        plt.xlabel('[um]')
-        plt.ylabel('[um]')
-        plt.title(channel)
-        plt.colorbar()
-        return ar
-    
     def xml2hdf(self):
         f1 = glob(self.directory + '//scalar*')
         f2 = glob(self.directory + '//scalar*.h5')
@@ -174,12 +150,80 @@ class ANA():
                                'Channel': name,
                                'Value': value,
                                'Backward': backward})
-            
+
             df.to_hdf(f + '.h5', key='df')
-    
-    def gaussianMix(self, spots, channel, backward, number=1):
+
+    def image(self, spot, channel, backward,
+              lim=None, scale=None, label=None, cmap=cm.afmhot,
+              **kwargs):
+
+        if isinstance(spot, list):
+            print('Can only show map of one spot at a time')
+            return
+
+        ar = self.channelData(spot, channel, backward, fill_empty=True).Value.values
+
+        if scale:
+            ar /= scale
+        
+        if not label:
+            label = ''
+
+        sz = self.param.MapPixSize[spot - 1]
+        ar = ar.reshape((sz, sz)).copy()
+        ar[::2] = np.fliplr(ar[::2])
+        
+        ar=np.fliplr(ar)
+
+        mSize = self.param.MapSize[spot - 1]
+        plt.imshow(ar, origin='bottomleft', extent=(0, mSize, 0, mSize), cmap=cmap, **kwargs)
+        if lim:
+            plt.clim(vmax=lim)
+        plt.xlabel('[$\mu$m]')
+        plt.ylabel('[$\mu$m]')
+        plt.title(channel)
+        cbar = plt.colorbar()
+        cbar.set_label(label, rotation=-90, va="bottom")
+        return ar
+
+    def hist(self, spots, channel, backward,
+             lim=None, scale=None, label=None, cmap=cm.afmhot,
+             **kwargs):
+
+        dd = self.channelData(spots, channel, backward).Value.dropna().values
+        if scale:
+            dd /= scale
+
+        if not lim:
+            lim = max(dd)
+
+        if not label:
+            label = ''
+        histtype = dict(histtype="step", linewidth=1, edgecolor='k')
+        n, bins, patches = plt.hist(dd[dd <= lim], **kwargs)
+
+        bin_centers = 0.5 * (bins[:-1] + bins[1:])
+
+        col = bin_centers - min(bin_centers)
+        col /= max(col)
+
+        for c, p in zip(col, patches):
+            plt.setp(p, 'facecolor', cmap(c))
+
+        plt.hist(dd[dd <= lim], **histtype, **kwargs)
+        plt.title(channel)
+        plt.xlabel(label)
+        plt.ylabel('Counts')
+
+    def gaussianMix(self, spots, channel, backward, number=1, lim=None, scale=None):
         gmm = sklearn.mixture.GaussianMixture(n_components=number, covariance_type='diag')
         d = self.channelData(spots, channel, backward).Value.values
+        if scale:
+            d /= scale
+
+        if lim:
+            d = d[d < lim]
+
         r = gmm.fit(d[:, np.newaxis])
         m = r.means_.flatten()
         w = r.weights_.flatten()
@@ -192,7 +236,7 @@ class ANA():
         d = self.spotData(spots)
         dd = d[(d['Channel'] == channel) & (d['Backward'] == backward)]
         if fill_empty:
-            sz = self.param.MapPixSize[spots-1]
+            sz = self.param.MapPixSize[spots - 1]
         
             ar = np.zeros(sz*sz) * np.nan
             ar[dd.Line.values] = dd.Value.values
@@ -222,10 +266,12 @@ class ANA():
 
 if __name__ == "__main__":
     from matplotlib import cm
-    directory = 'data_1mgmL'
+    directory = r'0217_A\default'
     ana = ANA(directory)
     # ana.xml2hdf()
     ana.read()
-    ana.hist(7, 'E-Modul', True, bins=100)
-    ana.image(7, 'E-Modul', True, cmap=cm.afmhot)
-    r = ana.gaussianMix(7, 'E-Modul', True, 2)
+    ana.hist(1, 'E-Modul', True, scale=1e9, lim=3, label='[GPa]', bins=128)
+    plt.show()
+    ana.image(1, 'E-Modul', True, scale=1e9, lim=3, label='[GPa]', cmap=cm.afmhot)
+    plt.show()
+    r = ana.gaussianMix(3, 'E-Modul', True, 2)
